Struct ricq_core::pb::cmd0x6ff::NewBizClientRegionCode
source · pub struct NewBizClientRegionCode {
pub nationid: Option<u64>,
pub provinceid: Option<u64>,
pub cityid: Option<u64>,
pub regionid: Option<u64>,
}Fields
nationid: Option<u64>provinceid: Option<u64>cityid: Option<u64>regionid: Option<u64>Implementations
sourceimpl NewBizClientRegionCode
impl NewBizClientRegionCode
sourcepub fn nationid(&self) -> u64
pub fn nationid(&self) -> u64
Returns the value of nationid, or the default value if nationid is unset.
sourcepub fn provinceid(&self) -> u64
pub fn provinceid(&self) -> u64
Returns the value of provinceid, or the default value if provinceid is unset.