pub struct SvcRegisterProxyMsgResp {
    pub result: Option<u32>,
    pub err_msg: Option<Vec<u8>>,
    pub flag: Option<u32>,
    pub seq: Option<u32>,
    pub info: Option<SvcResponseMsgInfo>,
    pub group_list: Vec<GroupList>,
    pub discuss_list: Vec<DiscussList>,
    pub group_msg: Vec<SvcResponsePbPullGroupMsgProxy>,
    pub discuss_msg: Vec<SvcPbResponsePullDisMsgProxy>,
    pub c2_c_msg: Option<Vec<u8>>,
    pub pub_account_msg: Option<Vec<u8>>,
    pub discuss_list_flag: Option<u32>,
}

Fields

result: Option<u32>err_msg: Option<Vec<u8>>flag: Option<u32>seq: Option<u32>info: Option<SvcResponseMsgInfo>group_list: Vec<GroupList>discuss_list: Vec<DiscussList>group_msg: Vec<SvcResponsePbPullGroupMsgProxy>discuss_msg: Vec<SvcPbResponsePullDisMsgProxy>c2_c_msg: Option<Vec<u8>>pub_account_msg: Option<Vec<u8>>discuss_list_flag: Option<u32>

Implementations

Returns the value of result, or the default value if result is unset.

Returns the value of err_msg, or the default value if err_msg is unset.

Returns the value of flag, or the default value if flag is unset.

Returns the value of seq, or the default value if seq is unset.

Returns the value of c2_c_msg, or the default value if c2_c_msg is unset.

Returns the value of pub_account_msg, or the default value if pub_account_msg is unset.

Returns the value of discuss_list_flag, or the default value if discuss_list_flag is unset.