pub struct C2cTempMessageHead {
    pub c2c_type: Option<i32>,
    pub service_type: Option<i32>,
    pub group_uin: Option<i64>,
    pub group_code: Option<i64>,
    pub sig: Option<Vec<u8>>,
    pub sig_type: Option<i32>,
    pub from_phone: Option<String>,
    pub to_phone: Option<String>,
    pub lock_display: Option<i32>,
    pub direction_flag: Option<i32>,
    pub reserved: Option<Vec<u8>>,
}

Fields

c2c_type: Option<i32>service_type: Option<i32>group_uin: Option<i64>group_code: Option<i64>sig: Option<Vec<u8>>sig_type: Option<i32>from_phone: Option<String>to_phone: Option<String>lock_display: Option<i32>direction_flag: Option<i32>reserved: Option<Vec<u8>>

Implementations

Returns the value of c2c_type, or the default value if c2c_type is unset.

Returns the value of service_type, or the default value if service_type is unset.

Returns the value of group_uin, or the default value if group_uin is unset.

Returns the value of group_code, or the default value if group_code is unset.

Returns the value of sig, or the default value if sig is unset.

Returns the value of sig_type, or the default value if sig_type is unset.

Returns the value of from_phone, or the default value if from_phone is unset.

Returns the value of to_phone, or the default value if to_phone is unset.

Returns the value of lock_display, or the default value if lock_display is unset.

Returns the value of direction_flag, or the default value if direction_flag is unset.

Returns the value of reserved, or the default value if reserved is unset.