pub struct DeltaHead {
pub total_len: Option<u64>,
pub offset: Option<u64>,
pub ack_offset: Option<u64>,
pub cookie: Option<Vec<u8>>,
pub ack_cookie: Option<Vec<u8>>,
pub result: Option<u32>,
pub flags: Option<u32>,
}Fields
total_len: Option<u64>offset: Option<u64>ack_offset: Option<u64>result: Option<u32>flags: Option<u32>Implementations
sourceimpl DeltaHead
impl DeltaHead
sourcepub fn total_len(&self) -> u64
pub fn total_len(&self) -> u64
Returns the value of total_len, or the default value if total_len is unset.
sourcepub fn offset(&self) -> u64
pub fn offset(&self) -> u64
Returns the value of offset, or the default value if offset is unset.
sourcepub fn ack_offset(&self) -> u64
pub fn ack_offset(&self) -> u64
Returns the value of ack_offset, or the default value if ack_offset is unset.
Returns the value of cookie, or the default value if cookie is unset.
Returns the value of ack_cookie, or the default value if ack_cookie is unset.