Struct ricq_core::pb::msg::ElemFlags2
source · pub struct ElemFlags2 {Show 14 fields
pub color_text_id: Option<u32>,
pub msg_id: Option<u64>,
pub whisper_session_id: Option<u32>,
pub ptt_change_bit: Option<u32>,
pub vip_status: Option<u32>,
pub compatible_id: Option<u32>,
pub insts: Vec<Inst>,
pub msg_rpt_cnt: Option<u32>,
pub src_inst: Option<Inst>,
pub longtitude: Option<u32>,
pub latitude: Option<u32>,
pub custom_font: Option<u32>,
pub pc_support_def: Option<PcSupportDef>,
pub crm_flags: Option<u32>,
}Fields
color_text_id: Option<u32>msg_id: Option<u64>whisper_session_id: Option<u32>ptt_change_bit: Option<u32>vip_status: Option<u32>compatible_id: Option<u32>insts: Vec<Inst>msg_rpt_cnt: Option<u32>src_inst: Option<Inst>longtitude: Option<u32>latitude: Option<u32>custom_font: Option<u32>pc_support_def: Option<PcSupportDef>crm_flags: Option<u32>Implementations
sourceimpl ElemFlags2
impl ElemFlags2
sourcepub fn color_text_id(&self) -> u32
pub fn color_text_id(&self) -> u32
Returns the value of color_text_id, or the default value if color_text_id is unset.
sourcepub fn msg_id(&self) -> u64
pub fn msg_id(&self) -> u64
Returns the value of msg_id, or the default value if msg_id is unset.
sourcepub fn whisper_session_id(&self) -> u32
pub fn whisper_session_id(&self) -> u32
Returns the value of whisper_session_id, or the default value if whisper_session_id is unset.
sourcepub fn ptt_change_bit(&self) -> u32
pub fn ptt_change_bit(&self) -> u32
Returns the value of ptt_change_bit, or the default value if ptt_change_bit is unset.
sourcepub fn vip_status(&self) -> u32
pub fn vip_status(&self) -> u32
Returns the value of vip_status, or the default value if vip_status is unset.
sourcepub fn compatible_id(&self) -> u32
pub fn compatible_id(&self) -> u32
Returns the value of compatible_id, or the default value if compatible_id is unset.
sourcepub fn msg_rpt_cnt(&self) -> u32
pub fn msg_rpt_cnt(&self) -> u32
Returns the value of msg_rpt_cnt, or the default value if msg_rpt_cnt is unset.
sourcepub fn longtitude(&self) -> u32
pub fn longtitude(&self) -> u32
Returns the value of longtitude, or the default value if longtitude is unset.
sourcepub fn latitude(&self) -> u32
pub fn latitude(&self) -> u32
Returns the value of latitude, or the default value if latitude is unset.
sourcepub fn custom_font(&self) -> u32
pub fn custom_font(&self) -> u32
Returns the value of custom_font, or the default value if custom_font is unset.