Struct ricq_core::pb::msg::HttpConnHead
source · pub struct HttpConnHead {Show 25 fields
pub uin: Option<u64>,
pub command: Option<u32>,
pub sub_command: Option<u32>,
pub seq: Option<u32>,
pub version: Option<u32>,
pub retry_times: Option<u32>,
pub client_type: Option<u32>,
pub pub_no: Option<u32>,
pub local_id: Option<u32>,
pub time_zone: Option<u32>,
pub client_ip: Option<u32>,
pub client_port: Option<u32>,
pub qzhttp_ip: Option<u32>,
pub qzhttp_port: Option<u32>,
pub spp_ip: Option<u32>,
pub spp_port: Option<u32>,
pub flag: Option<u32>,
pub key: Option<Vec<u8>>,
pub compress_type: Option<u32>,
pub origin_size: Option<u32>,
pub error_code: Option<u32>,
pub redirect: Option<RedirectMsg>,
pub command_id: Option<u32>,
pub service_cmdid: Option<u32>,
pub oidbhead: Option<TransOidbHead>,
}Fields
uin: Option<u64>command: Option<u32>sub_command: Option<u32>seq: Option<u32>version: Option<u32>retry_times: Option<u32>client_type: Option<u32>pub_no: Option<u32>local_id: Option<u32>time_zone: Option<u32>client_ip: Option<u32>client_port: Option<u32>qzhttp_ip: Option<u32>qzhttp_port: Option<u32>spp_ip: Option<u32>spp_port: Option<u32>flag: Option<u32>key: Option<Vec<u8>>compress_type: Option<u32>origin_size: Option<u32>error_code: Option<u32>redirect: Option<RedirectMsg>command_id: Option<u32>service_cmdid: Option<u32>oidbhead: Option<TransOidbHead>Implementations
sourceimpl HttpConnHead
impl HttpConnHead
sourcepub fn command(&self) -> u32
pub fn command(&self) -> u32
Returns the value of command, or the default value if command is unset.
sourcepub fn sub_command(&self) -> u32
pub fn sub_command(&self) -> u32
Returns the value of sub_command, or the default value if sub_command is unset.
sourcepub fn version(&self) -> u32
pub fn version(&self) -> u32
Returns the value of version, or the default value if version is unset.
sourcepub fn retry_times(&self) -> u32
pub fn retry_times(&self) -> u32
Returns the value of retry_times, or the default value if retry_times is unset.
sourcepub fn client_type(&self) -> u32
pub fn client_type(&self) -> u32
Returns the value of client_type, or the default value if client_type is unset.
sourcepub fn pub_no(&self) -> u32
pub fn pub_no(&self) -> u32
Returns the value of pub_no, or the default value if pub_no is unset.
sourcepub fn local_id(&self) -> u32
pub fn local_id(&self) -> u32
Returns the value of local_id, or the default value if local_id is unset.
sourcepub fn time_zone(&self) -> u32
pub fn time_zone(&self) -> u32
Returns the value of time_zone, or the default value if time_zone is unset.
sourcepub fn client_ip(&self) -> u32
pub fn client_ip(&self) -> u32
Returns the value of client_ip, or the default value if client_ip is unset.
sourcepub fn client_port(&self) -> u32
pub fn client_port(&self) -> u32
Returns the value of client_port, or the default value if client_port is unset.
sourcepub fn qzhttp_ip(&self) -> u32
pub fn qzhttp_ip(&self) -> u32
Returns the value of qzhttp_ip, or the default value if qzhttp_ip is unset.
sourcepub fn qzhttp_port(&self) -> u32
pub fn qzhttp_port(&self) -> u32
Returns the value of qzhttp_port, or the default value if qzhttp_port is unset.
sourcepub fn spp_ip(&self) -> u32
pub fn spp_ip(&self) -> u32
Returns the value of spp_ip, or the default value if spp_ip is unset.
sourcepub fn spp_port(&self) -> u32
pub fn spp_port(&self) -> u32
Returns the value of spp_port, or the default value if spp_port is unset.
sourcepub fn compress_type(&self) -> u32
pub fn compress_type(&self) -> u32
Returns the value of compress_type, or the default value if compress_type is unset.
sourcepub fn origin_size(&self) -> u32
pub fn origin_size(&self) -> u32
Returns the value of origin_size, or the default value if origin_size is unset.
sourcepub fn error_code(&self) -> u32
pub fn error_code(&self) -> u32
Returns the value of error_code, or the default value if error_code is unset.
sourcepub fn command_id(&self) -> u32
pub fn command_id(&self) -> u32
Returns the value of command_id, or the default value if command_id is unset.
sourcepub fn service_cmdid(&self) -> u32
pub fn service_cmdid(&self) -> u32
Returns the value of service_cmdid, or the default value if service_cmdid is unset.