pub struct NotOnlineFile {
Show 19 fields pub file_type: Option<i32>, pub sig: Option<Vec<u8>>, pub file_uuid: Option<Vec<u8>>, pub file_md5: Option<Vec<u8>>, pub file_name: Option<Vec<u8>>, pub file_size: Option<i64>, pub note: Option<Vec<u8>>, pub reserved: Option<i32>, pub subcmd: Option<i32>, pub micro_cloud: Option<i32>, pub bytes_file_urls: Vec<Vec<u8>>, pub download_flag: Option<i32>, pub danger_evel: Option<i32>, pub life_time: Option<i32>, pub upload_time: Option<i32>, pub abs_file_type: Option<i32>, pub client_type: Option<i32>, pub expire_time: Option<i32>, pub pb_reserve: Option<Vec<u8>>,
}

Fields

file_type: Option<i32>sig: Option<Vec<u8>>file_uuid: Option<Vec<u8>>file_md5: Option<Vec<u8>>file_name: Option<Vec<u8>>file_size: Option<i64>note: Option<Vec<u8>>reserved: Option<i32>subcmd: Option<i32>micro_cloud: Option<i32>bytes_file_urls: Vec<Vec<u8>>download_flag: Option<i32>danger_evel: Option<i32>life_time: Option<i32>upload_time: Option<i32>abs_file_type: Option<i32>client_type: Option<i32>expire_time: Option<i32>pb_reserve: Option<Vec<u8>>

Implementations

Returns the value of file_type, or the default value if file_type is unset.

Returns the value of sig, or the default value if sig is unset.

Returns the value of file_uuid, or the default value if file_uuid is unset.

Returns the value of file_md5, or the default value if file_md5 is unset.

Returns the value of file_name, or the default value if file_name is unset.

Returns the value of file_size, or the default value if file_size is unset.

Returns the value of note, or the default value if note is unset.

Returns the value of reserved, or the default value if reserved is unset.

Returns the value of subcmd, or the default value if subcmd is unset.

Returns the value of micro_cloud, or the default value if micro_cloud is unset.

Returns the value of download_flag, or the default value if download_flag is unset.

Returns the value of danger_evel, or the default value if danger_evel is unset.

Returns the value of life_time, or the default value if life_time is unset.

Returns the value of upload_time, or the default value if upload_time is unset.

Returns the value of abs_file_type, or the default value if abs_file_type is unset.

Returns the value of client_type, or the default value if client_type is unset.

Returns the value of expire_time, or the default value if expire_time is unset.

Returns the value of pb_reserve, or the default value if pb_reserve is unset.