pub struct Ptt {
Show 24 fields pub file_type: Option<i32>, pub src_uin: Option<i64>, pub file_uuid: Option<Vec<u8>>, pub file_md5: Option<Vec<u8>>, pub file_name: Option<String>, pub file_size: Option<i32>, pub reserve: Option<Vec<u8>>, pub file_id: Option<i32>, pub server_ip: Option<i32>, pub server_port: Option<i32>, pub bool_valid: Option<bool>, pub signature: Option<Vec<u8>>, pub shortcut: Option<Vec<u8>>, pub file_key: Option<Vec<u8>>, pub magic_ptt_index: Option<i32>, pub voice_switch: Option<i32>, pub ptt_url: Option<Vec<u8>>, pub group_file_key: Option<Vec<u8>>, pub time: Option<i32>, pub down_para: Option<Vec<u8>>, pub format: Option<i32>, pub pb_reserve: Option<Vec<u8>>, pub bytes_ptt_urls: Vec<Vec<u8>>, pub download_flag: Option<i32>,
}

Fields

file_type: Option<i32>src_uin: Option<i64>file_uuid: Option<Vec<u8>>file_md5: Option<Vec<u8>>file_name: Option<String>file_size: Option<i32>reserve: Option<Vec<u8>>file_id: Option<i32>server_ip: Option<i32>server_port: Option<i32>bool_valid: Option<bool>signature: Option<Vec<u8>>shortcut: Option<Vec<u8>>file_key: Option<Vec<u8>>magic_ptt_index: Option<i32>voice_switch: Option<i32>ptt_url: Option<Vec<u8>>group_file_key: Option<Vec<u8>>time: Option<i32>down_para: Option<Vec<u8>>format: Option<i32>pb_reserve: Option<Vec<u8>>bytes_ptt_urls: Vec<Vec<u8>>download_flag: Option<i32>

Implementations

Returns the value of file_type, or the default value if file_type is unset.

Returns the value of src_uin, or the default value if src_uin is unset.

Returns the value of file_uuid, or the default value if file_uuid is unset.

Returns the value of file_md5, or the default value if file_md5 is unset.

Returns the value of file_name, or the default value if file_name is unset.

Returns the value of file_size, or the default value if file_size is unset.

Returns the value of reserve, or the default value if reserve is unset.

Returns the value of file_id, or the default value if file_id is unset.

Returns the value of server_ip, or the default value if server_ip is unset.

Returns the value of server_port, or the default value if server_port is unset.

Returns the value of bool_valid, or the default value if bool_valid is unset.

Returns the value of signature, or the default value if signature is unset.

Returns the value of shortcut, or the default value if shortcut is unset.

Returns the value of file_key, or the default value if file_key is unset.

Returns the value of magic_ptt_index, or the default value if magic_ptt_index is unset.

Returns the value of voice_switch, or the default value if voice_switch is unset.

Returns the value of ptt_url, or the default value if ptt_url is unset.

Returns the value of group_file_key, or the default value if group_file_key is unset.

Returns the value of time, or the default value if time is unset.

Returns the value of down_para, or the default value if down_para is unset.

Returns the value of format, or the default value if format is unset.

Returns the value of pb_reserve, or the default value if pb_reserve is unset.

Returns the value of download_flag, or the default value if download_flag is unset.