pub struct SourceMsg {
    pub orig_seqs: Vec<i32>,
    pub sender_uin: Option<i64>,
    pub time: Option<i32>,
    pub flag: Option<i32>,
    pub elems: Vec<Elem>,
    pub type: Option<i32>,
    pub rich_msg: Option<Vec<u8>>,
    pub pb_reserve: Option<Vec<u8>>,
    pub src_msg: Option<Vec<u8>>,
    pub to_uin: Option<i64>,
    pub troop_name: Option<Vec<u8>>,
}

Fields

orig_seqs: Vec<i32>sender_uin: Option<i64>time: Option<i32>flag: Option<i32>elems: Vec<Elem>type: Option<i32>rich_msg: Option<Vec<u8>>pb_reserve: Option<Vec<u8>>src_msg: Option<Vec<u8>>to_uin: Option<i64>troop_name: Option<Vec<u8>>

Implementations

Returns the value of sender_uin, or the default value if sender_uin is unset.

Returns the value of time, or the default value if time is unset.

Returns the value of flag, or the default value if flag is unset.

Returns the value of type, or the default value if type is unset.

Returns the value of rich_msg, or the default value if rich_msg is unset.

Returns the value of pb_reserve, or the default value if pb_reserve is unset.

Returns the value of src_msg, or the default value if src_msg is unset.

Returns the value of to_uin, or the default value if to_uin is unset.

Returns the value of troop_name, or the default value if troop_name is unset.