Struct ricq_core::pb::notify::NotifyMsgBody
source · pub struct NotifyMsgBody {
pub opt_msg_gray_tips: Option<AioGrayTipsInfo>,
pub opt_msg_red_tips: Option<RedGrayTipsInfo>,
pub opt_msg_recall: Option<MessageRecallReminder>,
pub opt_general_gray_tip: Option<GeneralGrayTipInfo>,
pub qq_group_digest_msg: Option<QqGroupDigestMsg>,
pub service_type: i32,
}Fields
opt_msg_gray_tips: Option<AioGrayTipsInfo>opt_msg_red_tips: Option<RedGrayTipsInfo>opt_msg_recall: Option<MessageRecallReminder>opt_general_gray_tip: Option<GeneralGrayTipInfo>qq_group_digest_msg: Option<QqGroupDigestMsg>service_type: i32Trait Implementations
sourceimpl Clone for NotifyMsgBody
impl Clone for NotifyMsgBody
sourcefn clone(&self) -> NotifyMsgBody
fn clone(&self) -> NotifyMsgBody
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NotifyMsgBody
impl Debug for NotifyMsgBody
sourceimpl Default for NotifyMsgBody
impl Default for NotifyMsgBody
sourceimpl Message for NotifyMsgBody
impl Message for NotifyMsgBody
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self. Read more