pub struct GetFileListReqBody {
Show 15 fields pub group_code: Option<u64>, pub app_id: Option<u32>, pub folder_id: Option<String>, pub start_timestamp: Option<FileTimeStamp>, pub file_count: Option<u32>, pub max_timestamp: Option<FileTimeStamp>, pub all_file_count: Option<u32>, pub req_from: Option<u32>, pub sort_by: Option<u32>, pub filter_code: Option<u32>, pub uin: Option<u64>, pub field_flag: Option<u32>, pub start_index: Option<u32>, pub context: Option<Vec<u8>>, pub client_version: Option<u32>,
}

Fields

group_code: Option<u64>app_id: Option<u32>folder_id: Option<String>start_timestamp: Option<FileTimeStamp>file_count: Option<u32>max_timestamp: Option<FileTimeStamp>all_file_count: Option<u32>req_from: Option<u32>sort_by: Option<u32>filter_code: Option<u32>uin: Option<u64>field_flag: Option<u32>start_index: Option<u32>context: Option<Vec<u8>>client_version: Option<u32>

Implementations

Returns the value of group_code, or the default value if group_code is unset.

Returns the value of app_id, or the default value if app_id is unset.

Returns the value of folder_id, or the default value if folder_id is unset.

Returns the value of file_count, or the default value if file_count is unset.

Returns the value of all_file_count, or the default value if all_file_count is unset.

Returns the value of req_from, or the default value if req_from is unset.

Returns the value of sort_by, or the default value if sort_by is unset.

Returns the value of filter_code, or the default value if filter_code is unset.

Returns the value of uin, or the default value if uin is unset.

Returns the value of field_flag, or the default value if field_flag is unset.

Returns the value of start_index, or the default value if start_index is unset.

Returns the value of context, or the default value if context is unset.

Returns the value of client_version, or the default value if client_version is unset.