pub struct GetFileListRspBody {
Show 14 fields pub ret_code: Option<i32>, pub ret_msg: Option<String>, pub client_wording: Option<String>, pub is_end: Option<bool>, pub item_list: Vec<Item>, pub max_timestamp: Option<FileTimeStamp>, pub all_file_count: Option<u32>, pub filter_code: Option<u32>, pub safe_check_flag: Option<bool>, pub safe_check_res: Option<u32>, pub next_index: Option<u32>, pub context: Option<Vec<u8>>, pub role: Option<u32>, pub open_flag: Option<u32>,
}

Fields

ret_code: Option<i32>ret_msg: Option<String>client_wording: Option<String>is_end: Option<bool>item_list: Vec<Item>max_timestamp: Option<FileTimeStamp>all_file_count: Option<u32>filter_code: Option<u32>safe_check_flag: Option<bool>safe_check_res: Option<u32>next_index: Option<u32>context: Option<Vec<u8>>role: Option<u32>open_flag: Option<u32>

Implementations

Returns the value of ret_code, or the default value if ret_code is unset.

Returns the value of ret_msg, or the default value if ret_msg is unset.

Returns the value of client_wording, or the default value if client_wording is unset.

Returns the value of is_end, or the default value if is_end is unset.

Returns the value of all_file_count, or the default value if all_file_count is unset.

Returns the value of filter_code, or the default value if filter_code is unset.

Returns the value of safe_check_flag, or the default value if safe_check_flag is unset.

Returns the value of safe_check_res, or the default value if safe_check_res is unset.

Returns the value of next_index, or the default value if next_index is unset.

Returns the value of context, or the default value if context is unset.

Returns the value of role, or the default value if role is unset.

Returns the value of open_flag, or the default value if open_flag is unset.