Struct ricq_core::pb::Sub44GroupSyncMsg
source · pub struct Sub44GroupSyncMsg {Show 19 fields
pub msg_type: i32,
pub msg_seq: i64,
pub grp_code: i64,
pub ga_code: i64,
pub opt_uin1: i64,
pub opt_uin2: i64,
pub msg_buf: Vec<u8>,
pub auth_key: Vec<u8>,
pub msg_status: i32,
pub action_uin: i64,
pub action_time: i64,
pub cur_max_mem_count: i32,
pub next_max_mem_count: i32,
pub cur_mem_count: i32,
pub req_src_id: i32,
pub req_src_sub_id: i32,
pub inviter_role: i32,
pub ext_admin_num: i32,
pub process_flag: i32,
}Fields
msg_type: i32msg_seq: i64grp_code: i64ga_code: i64opt_uin1: i64opt_uin2: i64msg_buf: Vec<u8>auth_key: Vec<u8>msg_status: i32action_uin: i64action_time: i64cur_max_mem_count: i32next_max_mem_count: i32cur_mem_count: i32req_src_id: i32req_src_sub_id: i32inviter_role: i32ext_admin_num: i32process_flag: i32Trait Implementations
sourceimpl Clone for Sub44GroupSyncMsg
impl Clone for Sub44GroupSyncMsg
sourcefn clone(&self) -> Sub44GroupSyncMsg
fn clone(&self) -> Sub44GroupSyncMsg
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for Sub44GroupSyncMsg
impl Debug for Sub44GroupSyncMsg
sourceimpl Default for Sub44GroupSyncMsg
impl Default for Sub44GroupSyncMsg
sourceimpl Message for Sub44GroupSyncMsg
impl Message for Sub44GroupSyncMsg
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self. Read more