pub struct SystemMsg {Show 52 fields
pub sub_type: i32,
pub msg_title: String,
pub msg_describe: String,
pub msg_additional: String,
pub msg_source: String,
pub msg_decided: String,
pub src_id: i32,
pub sub_src_id: i32,
pub actions: Vec<SystemMsgAction>,
pub group_code: i64,
pub action_uin: i64,
pub group_msg_type: i32,
pub group_inviter_role: i32,
pub friend_info: Option<FriendInfo>,
pub group_info: Option<SGroupInfo>,
pub actor_uin: i64,
pub msg_actor_describe: String,
pub msg_additional_list: String,
pub relation: i32,
pub reqsubtype: i32,
pub clone_uin: i64,
pub discuss_uin: i64,
pub eim_group_id: i64,
pub msg_invite_extinfo: Option<MsgInviteExt>,
pub msg_pay_group_extinfo: Option<MsgPayGroupExt>,
pub source_flag: i32,
pub game_nick: Vec<u8>,
pub game_msg: Vec<u8>,
pub group_flagext3: i32,
pub group_owner_uin: i64,
pub doubt_flag: i32,
pub warning_tips: Vec<u8>,
pub name_more: Vec<u8>,
pub req_uin_faceid: i32,
pub req_uin_nick: String,
pub group_name: String,
pub action_uin_nick: String,
pub msg_qna: String,
pub msg_detail: String,
pub group_ext_flag: i32,
pub actor_uin_nick: String,
pub pic_url: String,
pub clone_uin_nick: String,
pub req_uin_business_card: String,
pub eim_group_id_name: String,
pub req_uin_pre_remark: String,
pub action_uin_qq_nick: String,
pub action_uin_remark: String,
pub req_uin_gender: i32,
pub req_uin_age: i32,
pub c2c_invite_join_group_flag: i32,
pub card_switch: i32,
}Fields
sub_type: i32msg_title: Stringmsg_describe: Stringmsg_additional: Stringmsg_source: Stringmsg_decided: Stringsrc_id: i32sub_src_id: i32actions: Vec<SystemMsgAction>group_code: i64action_uin: i64group_msg_type: i32group_inviter_role: i32friend_info: Option<FriendInfo>group_info: Option<SGroupInfo>actor_uin: i64msg_actor_describe: Stringmsg_additional_list: Stringrelation: i32reqsubtype: i32clone_uin: i64discuss_uin: i64eim_group_id: i64msg_invite_extinfo: Option<MsgInviteExt>msg_pay_group_extinfo: Option<MsgPayGroupExt>source_flag: i32game_nick: Vec<u8>game_msg: Vec<u8>group_flagext3: i32group_owner_uin: i64doubt_flag: i32warning_tips: Vec<u8>name_more: Vec<u8>req_uin_faceid: i32req_uin_nick: Stringgroup_name: Stringaction_uin_nick: Stringmsg_qna: Stringmsg_detail: Stringgroup_ext_flag: i32actor_uin_nick: Stringpic_url: Stringclone_uin_nick: Stringreq_uin_business_card: Stringeim_group_id_name: Stringreq_uin_pre_remark: Stringaction_uin_qq_nick: Stringaction_uin_remark: Stringreq_uin_gender: i32req_uin_age: i32c2c_invite_join_group_flag: i32card_switch: i32Trait Implementations
sourceimpl Message for SystemMsg
impl Message for SystemMsg
sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message to a buffer. Read more
sourcefn encode_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
Encodes the message to a newly allocated buffer.
sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>where
B: BufMut,
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8, Global>where
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes an instance of the message from a buffer. Read more
sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>where
B: Buf,
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moresourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>where
B: Buf,
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self. Read more