pub struct NotOnlineFile {Show 19 fields
pub file_type: Option<i32>,
pub sig: Option<Vec<u8>>,
pub file_uuid: Option<Vec<u8>>,
pub file_md5: Option<Vec<u8>>,
pub file_name: Option<Vec<u8>>,
pub file_size: Option<i64>,
pub note: Option<Vec<u8>>,
pub reserved: Option<i32>,
pub subcmd: Option<i32>,
pub micro_cloud: Option<i32>,
pub bytes_file_urls: Vec<Vec<u8>>,
pub download_flag: Option<i32>,
pub danger_evel: Option<i32>,
pub life_time: Option<i32>,
pub upload_time: Option<i32>,
pub abs_file_type: Option<i32>,
pub client_type: Option<i32>,
pub expire_time: Option<i32>,
pub pb_reserve: Option<Vec<u8>>,
}Fields
file_type: Option<i32>sig: Option<Vec<u8>>file_uuid: Option<Vec<u8>>file_md5: Option<Vec<u8>>file_name: Option<Vec<u8>>file_size: Option<i64>note: Option<Vec<u8>>reserved: Option<i32>subcmd: Option<i32>micro_cloud: Option<i32>bytes_file_urls: Vec<Vec<u8>>download_flag: Option<i32>danger_evel: Option<i32>life_time: Option<i32>upload_time: Option<i32>abs_file_type: Option<i32>client_type: Option<i32>expire_time: Option<i32>pb_reserve: Option<Vec<u8>>Implementations
sourceimpl NotOnlineFile
impl NotOnlineFile
sourcepub fn file_type(&self) -> i32
pub fn file_type(&self) -> i32
Returns the value of file_type, or the default value if file_type is unset.
sourcepub fn sig(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
pub fn sig(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
Returns the value of sig, or the default value if sig is unset.
sourcepub fn file_uuid(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
pub fn file_uuid(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
Returns the value of file_uuid, or the default value if file_uuid is unset.
sourcepub fn file_md5(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
pub fn file_md5(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
Returns the value of file_md5, or the default value if file_md5 is unset.
sourcepub fn file_name(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
pub fn file_name(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
Returns the value of file_name, or the default value if file_name is unset.
sourcepub fn file_size(&self) -> i64
pub fn file_size(&self) -> i64
Returns the value of file_size, or the default value if file_size is unset.
sourcepub fn note(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
pub fn note(&self) -> &[u8]ⓘNotable traits for &'_ mut [u8]impl<'_> Write for &'_ mut [u8]impl<'_> Read for &'_ [u8]
Returns the value of note, or the default value if note is unset.
sourcepub fn reserved(&self) -> i32
pub fn reserved(&self) -> i32
Returns the value of reserved, or the default value if reserved is unset.
sourcepub fn subcmd(&self) -> i32
pub fn subcmd(&self) -> i32
Returns the value of subcmd, or the default value if subcmd is unset.
sourcepub fn micro_cloud(&self) -> i32
pub fn micro_cloud(&self) -> i32
Returns the value of micro_cloud, or the default value if micro_cloud is unset.
sourcepub fn download_flag(&self) -> i32
pub fn download_flag(&self) -> i32
Returns the value of download_flag, or the default value if download_flag is unset.
sourcepub fn danger_evel(&self) -> i32
pub fn danger_evel(&self) -> i32
Returns the value of danger_evel, or the default value if danger_evel is unset.
sourcepub fn life_time(&self) -> i32
pub fn life_time(&self) -> i32
Returns the value of life_time, or the default value if life_time is unset.
sourcepub fn upload_time(&self) -> i32
pub fn upload_time(&self) -> i32
Returns the value of upload_time, or the default value if upload_time is unset.
sourcepub fn abs_file_type(&self) -> i32
pub fn abs_file_type(&self) -> i32
Returns the value of abs_file_type, or the default value if abs_file_type is unset.
sourcepub fn client_type(&self) -> i32
pub fn client_type(&self) -> i32
Returns the value of client_type, or the default value if client_type is unset.
sourcepub fn expire_time(&self) -> i32
pub fn expire_time(&self) -> i32
Returns the value of expire_time, or the default value if expire_time is unset.